using System;
using System.IO;
using System.IO.Compression;
using System.Web.UI;


namespace DMKI
{
    public static class Viewstate
    {

        public static byte[] Compress(byte[] data)
        {
            using (MemoryStream output = new MemoryStream())
            {
                using (GZipStream gzip = new GZipStream(output, CompressionMode.Compress, true))
                {
                    gzip.Write(data, 0, data.Length);
                }
                return output.ToArray();
            }
        }

        public static byte[] Decompress(byte[] data)
        {
            using (MemoryStream input = new MemoryStream())
            {
                input.Write(data, 0, data.Length);
                input.Position = 0;
                using (GZipStream gzip = new GZipStream(input, CompressionMode.Decompress, true))
                {
                    using (MemoryStream output = new MemoryStream())
                    {
                        byte[] buff = new byte[64];
                        int read = gzip.Read(buff, 0, buff.Length);
                        while (read > 0)
                        {
                            output.Write(buff, 0, read);
                            read = gzip.Read(buff, 0, buff.Length);
                        }
                        return output.ToArray();
                    }
                }
            }
        }

        public static object DecompressPageState(string viewState)
        {
            if (viewState == null) return null;
            byte[] bytes = Convert.FromBase64String(viewState);
            bytes = Decompress(bytes);
            return new LosFormatter().Deserialize(Convert.ToBase64String(bytes));
        }

        public static void CompressPageState(object viewState, Page page)
        {
            string viewStateString;
            using (StringWriter writer = new StringWriter())
            {
                new LosFormatter().Serialize(writer, viewState);
                viewStateString = writer.ToString();
            }
            byte[] bytes = Convert.FromBase64String(viewStateString);
            bytes = Compress(bytes);
            page.ClientScript.RegisterHiddenField ("__VSTATE", Convert.ToBase64String(bytes));
        }
    }
}